@@ -1,5 +1,5 @@
 from collections import OrderedDict, defaultdict
-from typing import List, Optional
+from typing import List, Optional, Tuple
 
 import pandas as pd
 
@@ -12,6 +12,11 @@ class ColumnBasedTable:
         self.columns = columns
         self.index2columns = {col.index: col for col in columns}
         self.df = self.as_dataframe()
+    
+    def shape(self) -> Tuple[int, int]:
+        if len(self.columns) == 0:
+            return 0, 0
+        return len(self.columns[0].values), len(self.columns)
 
     def get_column_by_index(self, col_idx: int) -> Column:
         return self.index2columns[col_idx]
@@ -44,9 +49,12 @@ class ColumnBasedTable:
             "columns": [col.__dict__ for col in self.columns],
         }
 
+    def __getitem__(self, item: Tuple[int, int]):
+        return self.columns[item[1]][item[0]]
+
     @staticmethod
     def from_dict(record: dict):
-        assert record.get('version', None) == "2"
+        assert record.get('version', None) == "2", record.get('version', None)
         return ColumnBasedTable(record['table_id'], [Column(**col) for col in record['columns']])
 
     @staticmethod
